import {
  select,
  scaleLinear, 
  extent, 
  axisLeft,
  axisBottom
} from 'd3';
import { getData } from './data';
import { dropDown } from './dropdown';
import { scatterPlot } from './scatter';

const height = 460;
const width  = 960;
const margin = {top: 25, right: 45, bottom: 90, left: 135};
const circleRadius = 10;

// Get the SVG from the DOM
const svg = select('svg')
.attr('height',height)
.attr('width',width);

let data;
let xColumn;
let yColumn;

const onXcolumnClicked = column => {
  xColumn = column;
  render();
};

const onYcolumnClicked = column => {
  yColumn = column;
  render();
};


const render = () => {
  // Render the dropdown Menus
  select('#y-menu')
    .call( dropDown, {
      options: data.columns,
      onOptionClicked: onYcolumnClicked,
    	selectedOption: yColumn
		});
  select('#x-menu')
    .call( dropDown, {
      options: data.columns,
      onOptionClicked: onXcolumnClicked,
    	selectedOption: xColumn
    });

  // Render the ScatterPlot
	svg.call(scatterPlot, {
    data,
    xColumn,
    yColumn,
    width,
    height,
    margin,
    circleRadius
  });

};

// Load Data and start rendering
getData()
  .then(loadedData => {
  	data = loadedData;
  	xColumn = data.columns[4];
  	yColumn = data.columns[3];
  	render();
});

