import {
  select,
  scaleLinear, 
  extent, 
  axisLeft,
  axisBottom
} from 'd3';

export const scatterPlot = (selection, props) => {
	const {
    data,
    xColumn,
    yColumn,
    width,
    height,
    margin,
    circleRadius
  } = props;
  
  const innerWidth = width-margin.left-margin.right;
	const innerHeight = height-margin.top-margin.bottom;

  const xValue = d => d[xColumn];
  const xAxisLabel = xColumn;
  
  const yValue = d => d[yColumn];
  const yAxisLabel = yColumn;

  // Set Scales of X and Y Axis
  const xScale = scaleLinear()
  	.domain(extent(data, xValue))
  	.range([0,innerWidth])
  	.nice();
  
  console.log(extent(data, xValue));

  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight,0])
  	.nice();
  
  // Format X Axis
  const xAxis = axisBottom(xScale)
  	.tickSize(-innerHeight)
  	.ticks(12)
  	.tickPadding(20);
  
  // Format Y Axis
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);

  // Add Main Bar Group
  const barGroup = selection.selectAll('.barGroup').data([null]);
  const barGroupEnter = barGroup
  	.enter().append('g')
  		.attr('class','barGroup');
  barGroupEnter
    .merge(barGroup)
      .attr('transform', `translate(${margin.left}, ${margin.top})`);

  // Add Y Axis Group
  const yAxisGroup = barGroup.select('.y-axis');
  const yAxisGroupEnter = barGroupEnter
    .append('g')
  		.attr('class', 'y-axis');
  yAxisGroup
    .merge(yAxisGroupEnter)
  	.call(yAxis)
 		.select('.domain').remove();
  
  const yAxisLabelText = yAxisGroupEnter
    .append('text')
  		.attr('class','axisLabel')
   		.attr('y',-90)
  		.attr('transform', 'rotate(-90)')
  		.attr('fill', 'black')
    	.attr('text-anchor', 'middle')
  	.merge(yAxisGroup.select('.axisLabel'))
  		.attr('x',-(innerHeight/2))
  		.text(yAxisLabel);
  
  // Add X Axis Group
  const xAxisGroup = barGroup.select('.x-axis');
  const xAxisGroupEnter = barGroupEnter
    .append('g')
   		.attr('class', 'x-axis');
 	xAxisGroup
  	.merge(xAxisGroupEnter)
   		.attr('transform', `translate(0, ${innerHeight})`)
	 	  .call(xAxis)
  	 	.select('.domain').remove();

  const xAxisLabelText = xAxisGroupEnter
    .append('text')
  		.attr('class','axisLabel')
  		.attr('fill', 'black')
  	.merge(xAxisGroup.select('.axisLabel'))
   		.attr('x',innerWidth/2)
  		.attr('y',margin.bottom-10)
	 		.text(xAxisLabel);

  // Add The Circles
  const circles = barGroup.merge(barGroupEnter).selectAll('circle').data(data);
  circles
 		.enter().append('circle')
 			.attr('cy', innerHeight/2)
 			.attr('cx', innerWidth/2)
  		.attr('r', 0)
  	.merge(circles)
  	.transition().duration(2000)
  	.delay( (d,i) => i*5)
 			.attr('cy', d => yScale(yValue(d)))
 			.attr('cx', d => xScale(xValue(d)))
 			.attr('r',circleRadius);
}